@@ -64,7 +64,7 @@
    XXX: For now, all masks are 8 bit. Make the channel depth settable.
 
  */
-class KRITAIMAGE_EXPORT KisMask : public KisNode, KisIndirectPaintingSupport
+class KRITAIMAGE_EXPORT KisMask : public KisNode, public KisIndirectPaintingSupport
 {
 
     Q_OBJECT
@@ -189,6 +189,8 @@ protected:
                                const QRect & rc,
                                PositionToFilthy maskPos) const;
 
+    KisKeyframeChannel *requestKeyframeChannel(const QString &id);
+
 private:
     friend class KisMaskProjectionPlane;
 
