@@ -50,7 +50,7 @@ public:
      * @param selection is a mask used by the layer to know
      * where to apply the filter/generator.
      */
-    KisSelectionBasedLayer(KisImageWSP image, const QString &name, KisSelectionSP selection, KisFilterConfiguration *filterConfig, bool useGeneratorRegistry = false);
+    KisSelectionBasedLayer(KisImageWSP image, const QString &name, KisSelectionSP selection, KisFilterConfigurationSP filterConfig, bool useGeneratorRegistry = false);
     KisSelectionBasedLayer(const KisSelectionBasedLayer& rhs);
     virtual ~KisSelectionBasedLayer();
 
@@ -188,6 +188,8 @@ protected:
      */
     void setUseSelectionInProjection(bool value) const;
 
+    KisKeyframeChannel *requestKeyframeChannel(const QString &id);
+
 public Q_SLOTS:
     void slotImageSizeChanged();
 
