@@ -26,14 +26,15 @@ class KisExperimentPaintOpSettings : public KisNoSizePaintOpSettings
 {
 public:
     KisExperimentPaintOpSettings();
-    ~KisExperimentPaintOpSettings();
+    virtual ~KisExperimentPaintOpSettings();
 
     bool paintIncremental();
-    QPainterPath brushOutline(const KisPaintInformation &info, OutlineMode mode) const;
+    QPainterPath brushOutline(const KisPaintInformation &info, OutlineMode mode);
 
-    QList<KisUniformPaintOpPropertySP> uniformProperties();
+    QList<KisUniformPaintOpPropertySP> uniformProperties(KisPaintOpSettingsSP settings);
 
 private:
+
     struct Private;
     const QScopedPointer<Private> m_d;
 };
