@@ -31,7 +31,7 @@ struct BrushReader {
     BrushReader(const KisBrushBasedPaintOpSettings *parent)
         : m_parent(parent)
     {
-        m_option.readOptionSetting(m_parent, false);
+        m_option.readOptionSetting(m_parent);
     }
 
     KisBrushSP brush() {
@@ -46,7 +46,7 @@ struct BrushWriter {
     BrushWriter(KisBrushBasedPaintOpSettings *parent)
         : m_parent(parent)
     {
-        m_option.readOptionSetting(m_parent, false);
+        m_option.readOptionSetting(m_parent);
     }
 
     ~BrushWriter() {
@@ -91,8 +91,7 @@ int KisBrushBasedPaintOpSettings::rate() const
 KisPaintOpSettingsSP KisBrushBasedPaintOpSettings::clone() const
 {
     KisPaintOpSettingsSP _settings = KisOutlineGenerationPolicy<KisPaintOpSettings>::clone();
-    KisBrushBasedPaintOpSettings *settings =
-        dynamic_cast<KisBrushBasedPaintOpSettings*>(_settings.data());
+    KisBrushBasedPaintOpSettingsSP settings = dynamic_cast<KisBrushBasedPaintOpSettings*>(_settings.data());
     settings->m_savedBrush = this->brush();
     return settings;
 }
@@ -113,7 +112,7 @@ KisBrushSP KisBrushBasedPaintOpSettings::brush() const
 QPainterPath KisBrushBasedPaintOpSettings::brushOutlineImpl(const KisPaintInformation &info,
                                                             OutlineMode mode,
                                                             qreal additionalScale,
-                                                            bool forceOutline) const
+                                                            bool forceOutline)
 {
     QPainterPath path;
 
@@ -146,7 +145,7 @@ QPainterPath KisBrushBasedPaintOpSettings::brushOutlineImpl(const KisPaintInform
     return path;
 }
 
-QPainterPath KisBrushBasedPaintOpSettings::brushOutline(const KisPaintInformation &info, OutlineMode mode) const
+QPainterPath KisBrushBasedPaintOpSettings::brushOutline(const KisPaintInformation &info, OutlineMode mode)
 {
     return brushOutlineImpl(info, mode, 1.0);
 }
@@ -175,7 +174,7 @@ void KisBrushBasedPaintOpSettings::setAngle(qreal value)
     w.brush()->setAngle(value);
 }
 
-qreal KisBrushBasedPaintOpSettings::angle() const
+qreal KisBrushBasedPaintOpSettings::angle()
 {
     return this->brush()->angle();
 }
@@ -187,7 +186,7 @@ void KisBrushBasedPaintOpSettings::setSpacing(qreal value)
     w.brush()->setSpacing(value);
 }
 
-qreal KisBrushBasedPaintOpSettings::spacing() const
+qreal KisBrushBasedPaintOpSettings::spacing()
 {
     return this->brush()->spacing();
 }
@@ -200,12 +199,12 @@ void KisBrushBasedPaintOpSettings::setAutoSpacing(bool active, qreal coeff)
 }
 
 
-bool KisBrushBasedPaintOpSettings::autoSpacingActive() const
+bool KisBrushBasedPaintOpSettings::autoSpacingActive()
 {
     return this->brush()->autoSpacingActive();
 }
 
-qreal KisBrushBasedPaintOpSettings::autoSpacingCoeff() const
+qreal KisBrushBasedPaintOpSettings::autoSpacingCoeff()
 {
     return this->brush()->autoSpacingCoeff();
 }
@@ -229,7 +228,7 @@ qreal KisBrushBasedPaintOpSettings::paintOpSize() const
 #include "kis_paintop_preset.h"
 #include "kis_paintop_settings_update_proxy.h"
 
-QList<KisUniformPaintOpPropertySP> KisBrushBasedPaintOpSettings::uniformProperties()
+QList<KisUniformPaintOpPropertySP> KisBrushBasedPaintOpSettings::uniformProperties(KisPaintOpSettingsSP settings)
 {
     QList<KisUniformPaintOpPropertySP> props =
         listWeakToStrong(m_uniformProperties);
@@ -241,7 +240,7 @@ QList<KisUniformPaintOpPropertySP> KisBrushBasedPaintOpSettings::uniformProperti
                     KisIntSliderBasedPaintOpPropertyCallback::Int,
                     "angle",
                     "Angle",
-                    this, 0);
+                    settings, 0);
 
             prop->setRange(0, 360);
 
@@ -271,7 +270,7 @@ QList<KisUniformPaintOpPropertySP> KisBrushBasedPaintOpSettings::uniformProperti
                     KisUniformPaintOpPropertyCallback::Bool,
                     "auto_spacing",
                     "Auto Spacing",
-                    this, 0);
+                    settings, 0);
 
             prop->setReadCallback(
                 [](KisUniformPaintOpProperty *prop) {
@@ -299,7 +298,7 @@ QList<KisUniformPaintOpPropertySP> KisBrushBasedPaintOpSettings::uniformProperti
                     KisDoubleSliderBasedPaintOpPropertyCallback::Double,
                     "spacing",
                     "Spacing",
-                    this, 0);
+                    settings, 0);
 
             prop->setRange(0.01, 10);
             prop->setSingleStep(0.01);
@@ -331,7 +330,7 @@ QList<KisUniformPaintOpPropertySP> KisBrushBasedPaintOpSettings::uniformProperti
         }
     }
 
-    return KisPaintOpSettings::uniformProperties() + props;
+    return KisPaintOpSettings::uniformProperties(settings) + props;
 }
 
 void KisBrushBasedPaintOpSettings::onPropertyChanged()
