@@ -22,13 +22,16 @@
 #include <brushengine/kis_paintop_settings.h>
 #include <kritapaintop_export.h>
 #include <kis_outline_generation_policy.h>
-#include "kis_brush.h"
+#include <kis_brush.h>
+#include <kis_shared.h>
+#include <kis_shared_ptr.h>
 
 
 class PAINTOP_EXPORT KisBrushBasedPaintOpSettings : public KisOutlineGenerationPolicy<KisPaintOpSettings>
 {
 public:
     KisBrushBasedPaintOpSettings();
+    virtual ~KisBrushBasedPaintOpSettings() {}
 
     ///Reimplemented
     virtual bool paintIncremental();
@@ -40,7 +43,7 @@ public:
     virtual int rate() const;
 
     using KisPaintOpSettings::brushOutline;
-    virtual QPainterPath brushOutline(const KisPaintInformation &info, OutlineMode mode) const;
+    virtual QPainterPath brushOutline(const KisPaintInformation &info, OutlineMode mode);
 
     ///Reimplemented
     virtual bool isValid() const;
@@ -53,27 +56,35 @@ public:
     KisPaintOpSettingsSP clone() const;
 
     void setAngle(qreal value);
-    qreal angle() const;
+    qreal angle();
 
     void setSpacing(qreal spacing);
-    qreal spacing() const;
+    qreal spacing();
 
     void setAutoSpacing(bool active, qreal coeff);
 
-    bool autoSpacingActive() const;
-    qreal autoSpacingCoeff() const;
+    bool autoSpacingActive();
+    qreal autoSpacingCoeff();
 
     void setPaintOpSize(qreal value);
     qreal paintOpSize() const;
 
-    QList<KisUniformPaintOpPropertySP> uniformProperties();
+    QList<KisUniformPaintOpPropertySP> uniformProperties(KisPaintOpSettingsSP settings);
 
 protected:
-    void onPropertyChanged();
-    QPainterPath brushOutlineImpl(const KisPaintInformation &info, OutlineMode mode, qreal additionalScale, bool forceOutline = false) const;
-    mutable KisBrushSP m_savedBrush;
 
+    void onPropertyChanged();
+    QPainterPath brushOutlineImpl(const KisPaintInformation &info, OutlineMode mode, qreal additionalScale, bool forceOutline = false);
+    mutable KisBrushSP m_savedBrush;
     QList<KisUniformPaintOpPropertyWSP> m_uniformProperties;
+
+private:
+
+    Q_DISABLE_COPY(KisBrushBasedPaintOpSettings)
+
 };
 
+class KisBrushBasedPaintOpSettings;
+typedef KisPinnedSharedPtr<KisBrushBasedPaintOpSettings> KisBrushBasedPaintOpSettingsSP;
+
 #endif // KIS_BRUSH_BASED_PAINTOP_SETTINGS_H
